@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.116_04';
+our $VERSION = '0.116_05';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Mar  3 16:58:17 2019 GMT
+# on Wed Mar  6 18:53:56 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1743,7 +1743,7 @@ __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
 __PACKAGE__->status( add => 25275, iridium => '-', 'Iridium 59', 'Tumbling' );
-__PACKAGE__->status( add => 25276, iridium => 'S', 'Iridium 60', '' );
+__PACKAGE__->status( add => 25276, iridium => '-', 'Iridium 60', 'Tumbling' );
 __PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 3
-#       Spare [S]: 7
-#    Tumbling [-]: 35
+#       Spare [S]: 6
+#    Tumbling [-]: 36
 #     Decayed [D]: 52
 
 1;
